OpentelemetryConfigBuilder

Struct OpentelemetryConfigBuilder 

pub struct OpentelemetryConfigBuilder {
    file: Option<Option<OpentelemetryFileExporterConfig>>,
    http: Option<Option<OpentelemetryHttpExporterConfig>>,
}
A builder to create an instance of OpentelemetryConfig.

Fields

file: Option<Option<OpentelemetryFileExporterConfig>>

In-progress value for file.

See OpentelemetryConfig.file

http: Option<Option<OpentelemetryHttpExporterConfig>>

In-progress value for http.

See OpentelemetryConfig.http

Implementations

Source

impl OpentelemetryConfigBuilder

pub fn file( &mut self, val: impl PossiblyOption<OpentelemetryFileExporterConfig>, ) -> &mut Self

Provide a value for file.

If no value is provided for file, build will use Default::default(). For convenience, this function accepts both OpentelemetryFileExporterConfig and Option<$T> .

file

Write spans to a file in OTLP JSON format.

pub fn http( &mut self, val: impl PossiblyOption<OpentelemetryHttpExporterConfig>, ) -> &mut Self

Provide a value for http.

If no value is provided for http, build will use Default::default(). For convenience, this function accepts both OpentelemetryHttpExporterConfig and Option<$T> .

http

Export spans via HTTP.

Source

impl OpentelemetryConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<OpentelemetryConfig, ConfigBuildError>

Try to construct a new OpentelemetryConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.