OpentelemetryFileExporterConfigBuilder

Struct OpentelemetryFileExporterConfigBuilder 

pub struct OpentelemetryFileExporterConfigBuilder {
    path: Option<CfgPath>,
    batch: OpentelemetryBatchConfigBuilder,
}
A builder to create an instance of OpentelemetryFileExporterConfig.

Fields

path: Option<CfgPath>

In-progress value for path.

See OpentelemetryFileExporterConfig.path

batch: OpentelemetryBatchConfigBuilder

In-progress value for batch.

See OpentelemetryFileExporterConfig.batch

Implementations

Source

impl OpentelemetryFileExporterConfigBuilder

pub fn path(&mut self, val: CfgPath) -> &mut Self

Provide a value for path.

If no value is provided for path, build will fail with an error.

path

The path to write the JSON file to.

pub fn batch(&mut self) -> &mut OpentelemetryBatchConfigBuilder

Return a mutable reference to the inner builder for batch.

batch

Configuration for how to batch writes.

Source

impl OpentelemetryFileExporterConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<OpentelemetryFileExporterConfig, ConfigBuildError>

Try to construct a new OpentelemetryFileExporterConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.