OpentelemetryHttpExporterConfigBuilder

Struct OpentelemetryHttpExporterConfigBuilder 

pub struct OpentelemetryHttpExporterConfigBuilder {
    endpoint: Option<String>,
    batch: OpentelemetryBatchConfigBuilder,
    timeout: Option<Duration>,
}
A builder to create an instance of OpentelemetryHttpExporterConfig.

Fields

endpoint: Option<String>

In-progress value for endpoint.

See OpentelemetryHttpExporterConfig.endpoint

batch: OpentelemetryBatchConfigBuilder

In-progress value for batch.

See OpentelemetryHttpExporterConfig.batch

timeout: Option<Duration>

In-progress value for timeout.

See OpentelemetryHttpExporterConfig.timeout

Implementations

Source

impl OpentelemetryHttpExporterConfigBuilder

pub fn endpoint(&mut self, val: impl StringOrStr) -> &mut Self

Provide a value for endpoint.

If no value is provided for endpoint, build will fail with an error. For convenience, this function accepts both String and &str.

endpoint

HTTP(S) endpoint to send spans to.

For Jaeger, this should be something like: http://localhost:4318/v1/traces

pub fn batch(&mut self) -> &mut OpentelemetryBatchConfigBuilder

Return a mutable reference to the inner builder for batch.

batch

Configuration for how to batch exports.

pub fn timeout(&mut self, val: Duration) -> &mut Self

Provide a value for timeout.

If no value is provided for timeout, build will use Default::default().

timeout

Timeout for sending data.

Source

impl OpentelemetryHttpExporterConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<OpentelemetryHttpExporterConfig, ConfigBuildError>

Try to construct a new OpentelemetryHttpExporterConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.